Practice
-----------------------------------------------------

Please try to solve each of the following problems. Do not use any outside
resources.

Problems
==============

.. selectquestion:: iwgex1-p3-has22-ps-sq-tog
   :fromid: has22_Write, has22_Parsons-Version-A
   :toggle: lock
   :points: 10

.. selectquestion:: iwgex1-p3-filter-words-ps-sq-tog
   :fromid: filter_words_less_than_3_chars, filter-strings-Parsons-Version-pilot
   :toggle: lock
   :points: 10

.. selectquestion:: iwgex1-p3-get-middle-ps-sq-tog
   :fromid: get-middle, get-middle-Parsons-Version-pilot
   :toggle: lock
   :points: 10

.. selectquestion:: iwgex1-p3-sum13-ps-sq-tog
   :fromid: sum13_writecode_test_1_v2, sum13-Parsons-version-pilot
   :toggle: lock
   :points: 10

.. selectquestion:: iwgex1-p3-dict-to-list-ps-sq-tog
   :fromid: dict_to_list_pilot, dict_to_list_pp_pilot
   :toggle: lock
   :points: 10

Feedback
==================================

.. shortanswer:: iwgex1-p3-ex-ps-sa-tog

   Please provide feedback here. Please share any comments, problems, or suggestions.

What to do next
============================
Click on the following link: `Post Test <p3-post.html>`_
